@@ -19,7 +19,7 @@ cloglog <- function(x) log(-log(1-x))
 #' @export
 nimEquals <- function(x1, x2) if(x1 == x2) 1 else 0 ## "equals" conflicts with a usage in testthat
 #' @export
-logfact <- function(x) lfactorial(x)
+logfact <- function(x) lfactorial(x) ## lgamma(x+1) (from R) not equivalent to lgamma1p(x) (from our C). lgamma seems to be endowed with setting numerically 0 values to zero.
 #' @export
 loggam <- function(x) lgamma(x)
 #' @export
@@ -29,11 +29,11 @@ phi <- function(x) pnorm(x) ## same as iprobit
 #' @export
 pow <- function(x1, x2) x1^x2
 #' @export
-nimStep <- function(x) ifelse(x >= 0, 1, 0) ## We rename step to nimStep before execution to avoid masking the R step function
+nimStep <- function(x) ifelse(x >= 0, 1L, 0L) ## We rename step to nimStep before execution to avoid masking the R step function
 #' @export
 inverse <- function(x) solve(x)
 #' @export
-cube <- function(x) x^3
+cube <- function(x) x*x*x ## Doing is this way instead of x^3 makes it numerically identical to eigen's cube
 #' @export
 inprod <- function(v1, v2) sum(v1 * v2)
 #' @export
