@@ -633,6 +633,51 @@ rmvt_chol <- function(n = 1, mu, cholesky, df, prec_param = TRUE) {
         as.double(df), as.double(prec_param))
 }
 
+#' The LKJ Distribution for the Cholesky Factor of a Correlation Matrix
+#'
+#' Density and random generation for the LKJ distribution for the Cholesky factor of a correlation matrix.
+#'
+#' @name LKJ
+#'
+#' @aliases lkj dlkj rlkj lkj_corr lkj_corr_cholesky
+#' 
+#' @param x upper-triangular Cholesky factor of a correlation matrix.
+#' @param n number of observations (only \code{n=1} is handled currently).
+#' @param eta shape parameter.
+#' @param p size of the correlation matrix (number of rows and columns); required because random generation function has no information about dimension of matrix to generate without this argument.
+#' @param log logical; if TRUE, probability density is returned on the log scale.
+#' @author Christopher Paciorek
+#' @details See Stan Development Team for mathematical details. 
+#' @return \code{dlkj_corr_cholesky} gives the density and \code{rlkj_corr_cholesky} generates random deviates.
+#' @references Stan Development Team. Stan Reference Functions, version 2.27.
+#' @seealso \code{\link{Distributions}} for other standard distributions
+#' 
+#' @examples
+#' eta <- 3
+#' x <- rlkj_corr_cholesky(1, eta, 5)
+#' dlkj_corr_cholesky(x, eta, 5)
+#' 
+NULL
+
+#' @rdname LKJ
+#' @export
+dlkj_corr_cholesky <- function(x, eta, p, log = FALSE) {
+  # x should be upper triangular
+                                        # FIXME: allow x to be lower tri
+    if (storage.mode(x) != "double") 
+        storage.mode(x) <- "double"
+    .Call(C_dlkj_corr_cholesky, x, as.double(eta), as.integer(p), as.logical(log))
+}
+
+#' @rdname LKJ
+#' @export
+rlkj_corr_cholesky <- function(n = 1, eta, p) {
+    if(n != 1) warning('rlkj_corr_cholesky only handles n = 1 at the moment')
+    out <- .Call(C_rlkj_corr_cholesky, as.double(eta), as.integer(p))
+    if(!is.null(out)) out <- matrix(out, nrow = p, ncol = p)
+    return(out)
+}
+
 #' Interval calculations 
 #'
 #' Calculations to handle censoring
