@@ -194,6 +194,7 @@ callToSkipInEigenization <- c('copy',
                               'rankSample',
                               'nimArr_dmnorm_chol',
                               'nimArr_dmvt_chol',
+                              'nimArr_dlkj_corr_cholesky',
                               'nimArr_dwish_chol',
                               'nimArr_dinvwish_chol',
                               'nimArr_dcar_normal',
@@ -204,6 +205,7 @@ callToSkipInEigenization <- c('copy',
                               'nimArr_ddirch',
                               'nimArr_rmnorm_chol',
                               'nimArr_rmvt_chol',
+                              'nimArr_rlkj_corr_cholesky',
                               'nimArr_rwish_chol',
                               'nimArr_rinvwish_chol',
                               'nimArr_rcar_normal',
